summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Lib/pprint.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/pprint.py b/Lib/pprint.py
index 716f35d..e92b639 100644
--- a/Lib/pprint.py
+++ b/Lib/pprint.py
@@ -26,7 +26,7 @@ pformat()
Format a Python object into a pretty-printed representation.
pprint()
- Pretty-print a Python object to a stream [default is sys.sydout].
+ Pretty-print a Python object to a stream [default is sys.stdout].
saferepr()
Generate a 'standard' repr()-like value, but protect against recursive
@@ -49,7 +49,7 @@ _type = type
def pprint(object, stream=None, indent=1, width=80, depth=None):
"""Pretty-print a Python object to a stream [default is sys.sydout]."""
printer = PrettyPrinter(
stream=stream, indent=indent, width=width, depth=depth)
printer.pprint(object)
@@ -49,7 +49,7 @@ _type = type
def pprint(object, stream=None, indent=1, width=80, depth=None):
- """Pretty-print a Python object to a stream [default is sys.sydout]."""
+ """Pretty-print a Python object to a stream [default is sys.stdout]."""
printer = PrettyPrinter(
stream=stream, indent=indent, width=width, depth=depth)